@@ -89,17 +89,6 @@ static bool isdir (const char *filename)
 	return false;
 }
 
-static bool is_mounted(const char *mount_dir)
-{
-	FILE *f = setmntent("/etc/mtab", "r");
-	for (;;) {
-		struct mntent *m = getmntent(f);
-		if (!m) break;
-		if (strcmp(mount_dir, m->mnt_dir)==0) return true;
-	}
-	return false;
-}
-
 void add_crypt_point (const char *stash_dir, const char *mount_dir)
 {
 	cryptPoints.push_back (CryptPoint (stash_dir, mount_dir));
@@ -435,7 +424,7 @@ gboolean on_button_release (GtkWidget *widget, GdkEventButton *event, gpointer d
 	return TRUE;
 }
 
-static const char *about_authors[] = { "Tom Morton <t-morton@blueyonder.co.uk>" };
+static const char *about_authors[] = { "Tom Morton <tomm@riseup.net>" };
 /*static const char *about_translators = "Christoph Langner <mail@christoph-langner.de>\n"
 		"Jean-Sébastien Bour <sufflope@sufflope.net>\n"
 		"Phantom X <megaphantomx@bol.com.br>";*/
